package jp.jasminesoft.wagby.tests.models.customer;

import jp.jasminesoft.jfc.test.support.selenide.ComboBox;
import jp.jasminesoft.jfc.test.support.selenide.DateTextBox;
import jp.jasminesoft.jfc.test.support.selenide.ListBox;
import jp.jasminesoft.jfc.test.support.selenide.Postcode;
import jp.jasminesoft.jfc.test.support.selenide.RadioButton;
import jp.jasminesoft.jfc.test.support.selenide.WebContainerModelitem;
import jp.jasminesoft.jfc.test.support.selenide.WebModel;
import jp.jasminesoft.jfc.test.support.selenide.WebModelitem;
import jp.jasminesoft.jfc.test.support.selenide.WebMultiModelitem;

/**
 * Customer モデルの情報を保持するクラス。
 *
 * @author JasmineSoft
 * @version $Revision$ $Date$
 */
public class Customer extends WebModel {

    /**
     * コンストラクタ。
     */
    public Customer() {
        super("customer");
    }

    /** customer/customerid */
    public final WebModelitem<?> customerid
            = new WebModelitem<>(this, "customerid");

    /** customer/name */
    public final WebModelitem<?> name
            = new WebModelitem<>(this, "name");

    /** customer/kananame */
    public final WebModelitem<?> kananame
            = new WebModelitem<>(this, "kananame");

    /**
     * customer/companyname
     * 追記型リストボックス項目は {@link ComboBox} を利用する。
     */
    public final ComboBox companyname
            = new ComboBox(this, "companyname");

    /** customer/companykananame */
    public final WebModelitem<?> companykananame
            = new WebModelitem<>(this, "companykananame");

    /** customer/deptname */
    public final WebModelitem<?> deptname
            = new WebModelitem<>(this, "deptname");

    /**
     * customer/customertype
     * ラジオボタン項目は {@link RadioButton} を利用する。
     */
    public final RadioButton customertype
            = new RadioButton(this, "customertype");

    /** customer/title */
    public final WebModelitem<?> title
            = new WebModelitem<>(this, "title");

    /**
     * customer/zipcode
     * 郵便番号項目は {@link Postcode} を利用する。
     */
    public final Postcode zipcode
            = new Postcode(this, "zipcode");

    /** customer/address */
    public final WebModelitem<?> address
            = new WebModelitem<>(this, "address");

    /**
     * customer/email
     * 繰り返し項目は {@link WebMultiModelitem} を利用する。
     */
    public final WebMultiModelitem<?> email
            = new WebMultiModelitem<>(this, "email");

    /** customer/tel */
    public final WebModelitem<?> tel
            = new WebModelitem<>(this, "tel");

    /** customer/fax */
    public final WebModelitem<?> fax
            = new WebModelitem<>(this, "fax");

    /**
     * customer/report
     * 繰り返しコンテナを表現する専用内部クラスを利用する。
     */
    public final Report report = new Report(this, "report");

    /**
     * customer の繰り返しコンテナ report 内の各入力項目を保持するクラス。
     * {@link WebContainerModelitem} を継承する。
     */
    public class Report extends WebContainerModelitem<Report> {

        /**
         * コンストラクタ。
         * @param model モデル情報
         * @param name コンテナ名
         */
        public Report(WebModel model, String name) {
            super(model, name);
        }

        /**
         * コンストラクタ。
         * @param model モデル情報
         * @param name コンテナ名
         * @param index コンテナ番号
         */
        public Report(WebModel model, String name, int index) {
            super(model, name, index);
        }

        /** {@inheritDoc} */
        @Override
        protected Report newInstance(int idx) {
            return new Report(model, name, idx);
        }

        /** customer/report/rid */
        public final WebModelitem<?> rid = new WebModelitem<>(this, "rid");

        /**
         * customer/report/rdate
         * 日付項目は {@link DateTextBox} を利用する。
         */
        public final DateTextBox rdate = new DateTextBox(this, "rdate");

        /**
         * customer/report/rstatus
         * リストボックス項目は {@link ListBox} を利用する。
         */
        public final ListBox rstatus = new ListBox(this, "rstatus");

        /** customer/report/rnote */
        public final WebModelitem<?> rnote = new WebModelitem<>(this, "rnote");
    }

    /** customer/updateuserid */
    public final WebModelitem<?> updateuserid
            = new WebModelitem<>(this, "updateuserid");

    /** customer/insertrec */
    public final WebModelitem<?> insertrec
            = new WebModelitem<>(this, "insertrec");

    /** customer/updaterec */
    public final WebModelitem<?> updaterec
            = new WebModelitem<>(this, "updaterec");
}
