package jp.jasminesoft.wagby.tests.t001_Customer;

import static com.codeborne.selenide.CollectionCondition.*;
import static com.codeborne.selenide.Condition.*;
import static com.codeborne.selenide.Selenide.*;
import static jp.jasminesoft.jfc.test.support.selenide.Operations.*;
import static org.hamcrest.CoreMatchers.*;
import static org.junit.Assert.*;

import jp.jasminesoft.wagby.tests.models.customer.CustomerCp;
import jp.jasminesoft.wagby.tests.models.customer.CustomerLp;
import jp.jasminesoft.wagby.tests.models.customer.CustomerUlp;
import org.junit.FixMethodOrder;
import org.junit.Test;
import org.junit.runners.MethodSorters;

/**
 * 3. Customer モデルの一覧更新画面のテスト
 *
 * @author JasmineSoft
 * @version $Revision$ $Date$
 */
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class CustomerTest3 {

    /**
     * ログオン
     */
    @Test
    public void test00ログオン() {
        logon("admin", "wagby");
        pageTitle().shouldHave(exactText("メニュー"));
    }

    /**
     * 顧客情報一覧更新へ遷移
     */
    @Test
    public void test01顧客情報一覧更新へ遷移() {
        pageTitle().shouldHave(exactText("メニュー"));

        // メニューから顧客情報 検索画面へ遷移
        selectMenu("サービス", "顧客情報検索");
        pageTitle().shouldHave(exactText("顧客情報 検索"));
    }

    /**
     * 前処理: 一覧更新対象データの絞り込み。
     */
    @Test
    public void test02一覧更新対象データの絞り込み() {
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // 一覧更新対象データを検索画面で絞り込んでおく。
        CustomerCp condition = new CustomerCp();
        condition.name.val("ジャスミン太郎");

        // 「検索の実行」ボタンをクリック。
        search();
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // 検索結果件数の確認。
        $(".display_resultcount").shouldHave(text(
                "検索条件に合致したデータは1件見つかりました。"));

        // 「一覧更新へ」ボタンをクリック。
        clickUpdateListPageButton();
        pageTitle().shouldHave(exactText("顧客情報 一覧更新"));
    }

    /**
     * 一覧更新のテスト
     */
    @Test
    public void test03一覧更新のテスト() {
        pageTitle().shouldHave(exactText("顧客情報 一覧更新"));

        // WebUpdateListModel を継承した一覧更新部を表すモデル。
        CustomerUlp updateList = new CustomerUlp();
        // 1行目のデータを取得
        CustomerUlp record01 = updateList.get(1);

        // 1行目の「コピー」ボタンをクリック。
        // 2行目のコピーされたデータが取得できる。
        CustomerUlp copyRecord02 = record01.clickCopyButton();

        // 名前を変更する。
        copyRecord02.name.val("ジャスミン次郎(※一覧更新画面で作成)");

        // 2行目の「コピー」ボタンをクリック。
        // 3行目の新規データが取得できる。
        CustomerUlp newRecord03 = copyRecord02.clickNewButton();

        newRecord03.name.val("ジャスミン三郎(※一覧更新画面で作成)");

        // ラジオボタン
        newRecord03.customertype.val("医療");
        newRecord03.title.val("外科部長");

        // 検索画面でも郵便番号と住所の同期が可能。
        newRecord03.zipcode.val("104-0054").sync();
        // 住所項目: 郵便番号と同期後の値を確認。
        newRecord03.address.shouldHave("東京都中央区勝どき");

        newRecord03.tel.val("03-6811-1173");

        //「保存」ボタンをクリック
        save();
        // メッセージチェック。
        infos().shouldBe(size(1));
        infos().shouldHave(exactTexts(
                "1件の顧客情報データを新規登録しました。"
                + "1件の顧客情報データをコピー登録しました。"));
        pageTitle().shouldHave(exactText("顧客情報 一覧"));
    }

    /**
     * 一覧更新結果の確認
     */
    @Test
    public void test04一覧更新結果の確認() {
        pageTitle().shouldHave(exactText("顧客情報 一覧"));

        // 「検索画面へ」ボタンをクリック
        clickSearchPageButton();
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // 一覧更新対象データを検索画面で絞り込んでおく。
        CustomerCp condition = new CustomerCp();
        condition.name.val("(※一覧更新画面で作成)");

        // 「検索の実行」ボタンをクリック。
        search();
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // 検索結果件数の確認。
        $(".display_resultcount").shouldHave(text(
                "検索条件に合致したデータは2件見つかりました。"));

        // 「一覧画面へ」ボタンをクリック。
        clickListPageButton();
        pageTitle().shouldHave(exactText("顧客情報 一覧"));
        // 検索結果件数の確認。
        $(".display_resultcount").shouldHave(text(
                "2件中、1件目から2件目を表示しています。"));

        CustomerLp list = new CustomerLp();
        // 1行目のデータの確認。
        CustomerLp record01 = list.get(1);

        record01.name.shouldHave("ジャスミン次郎(※一覧更新画面で作成)");
        record01.customertype.shouldHave("地方公共団体");
        record01.title.shouldHave("一般");
        record01.zipcode.shouldHave("901-2227");
        record01.address.shouldHave("沖縄県宜野湾市宇地泊");
        record01.email.shouldHave(
                "taro@jasminesoft.co.jp", "sales@jasminesoft.co.jp");
        record01.tel.shouldHave("098-890-6036");

        // 1行目のデータの確認。
        CustomerLp record02 = list.get(2);
        record02.name.shouldHave("ジャスミン三郎(※一覧更新画面で作成)");
        record02.customertype.shouldHave("医療");
        record02.title.shouldHave("外科部長");
        record02.zipcode.shouldHave("104-0054");
        record02.address.shouldHave("東京都中央区勝どき");
        record02.tel.shouldHave("03-6811-1173");
    }

    /**
     * 一覧更新での削除
     */
    @Test
    public void test05一覧更新での削除テスト() {
        pageTitle().shouldHave(exactText("顧客情報 一覧"));

        // 「検索画面へ」ボタンをクリック
        clickSearchPageButton();
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // 検索条件が残っていることを確認。
        CustomerCp condition = new CustomerCp();
        condition.name.shouldHave("(※一覧更新画面で作成)");

        // 念の為、検索を再実行。
        search();
        pageTitle().shouldHave(exactText("顧客情報 検索"));

        // 検索結果件数の確認。
        $(".display_resultcount").shouldHave(text(
                "検索条件に合致したデータは2件見つかりました。"));

        // 「一覧更新へ」ボタンをクリック。
        clickUpdateListPageButton();
        pageTitle().shouldHave(exactText("顧客情報 一覧更新"));

        // 以下、表示されているデータ全てを削除する。
        CustomerUlp updateList = new CustomerUlp();
        // データ件数を取得。
        int rowSize = updateList.size();
        // データの件数分ループ処理を行う。
        for (int i = 1; i <= rowSize; i++) {
            // i行目の「削除」チェックボックスをクリック。
            updateList.get(i).clickDeleteCheckBox();
        }

        //「保存」ボタンをクリック
        save();
        pageTitle().shouldHave(exactText("顧客情報 一覧"));

        // メッセージチェック。
        infos().shouldHave(size(1));
        infos().shouldBe(exactTexts("2件の顧客情報データを削除しました。"));
    }

    /**
     * ログオフ
     */
    @Test
    public void test99ログオフ() {
        logoff();
    }
}
